# Grundlagen

## Kernschießmaschinen

Kernschießmaschinen sind industrielle Anlagen, welche in der Gießereiindustrie eingesetzt werden. Sie stellen aus Sand und Bindemitteln Kerne her, welche beim Gießvorgang die Hohlräume der zu gießenden Form ausfüllen. Nach ihrer Verwendung werden die Kerne wieder aufgelöst und die Rohmaterialien wieder dem Prozess zugeführt.
Die Kernschießmaschinen von Laempe arbeiten komplett automatisch und können mehrere Kerne pro Minute herstellen. Sie bestehen, wie viele industrielle Anlagen, aus einer zentralen Steuereinheit und einer vielzahl von Sensoren und Aktoren. Mit ihnen wird eine festgelegte Sequenz von Schritten orchestriert, die unteranderem das Ein-/Ausfahren des Kernkastens, das Schließen der Seitenteile oder das Befüllen der Kernform beinhalten. Eine genaue Aufzählung folgt im [Kapitel 3](30_Implementierung.md).

## Problemstellung

Mit dieser Arbeit werden diverse Konzepte zur Überwachung maschineller Anlagen erforscht. Dabei soll ein autonomes Meldesystem aufgebaut werden, welches auf schleichende Probleme aufmerksam machen kann bzw. zur Optimierung des Betriebsablaufes beiträgt. Um dies zu erreichen müssen Messwerte erhoben, analysiert und schließlich gespeichert werden. Die möglichen Auslegungen dieser Teilfunktionen sind im [2. Kapitel Theorie](20_Theorie.md) aufgelistet. Folgende Darstellung zeigt die Bestandteile des entwickelten Monitoring-Systems: 

![Übersicht](out/diagrams/uebersicht/uebersicht.svg)

Bei der Erhebung der Messwerte entstehen viele Datenpunkte, die einzeln betrachtet keine große Aussagekraft besitzen. Der Schritt der Datenverarbeitung kombiniert die eingehenden Datenströme und extrahiert für den Endnutzer relvante Informationen. Für die Übertragung von den Sensoren zur datenverarbeitenden Einheit werden Kommunikationsbusse eingesetzt, welche bereits in den Kernschießmaschinen verwendet werden. Es soll nach Möglichkeit kein weiterer Feldbus einer anderen Technologie hinzugefügt werden, um die Kosten für die Integration möglichst gering zu halten. Die einzubauenden Sensoren werden am bestehenden Feldbus angeschlossen, welcher wiederum zu einem Interfacemodul führt. Für die Koordination der Interfacemodule ist in jeder Anlage bereits eine zentrale Steuerungseinheit (SPS oder CPU genannt) zuständig. Diese Steuerungen verwenden ein meist auf Ethernet basiertes Kommunikationsprotokoll, um mit dem Rest der Anlage zu kommunizieren. [] Ihre Kommunikationspartner können zum Beispiel Interfacemodule, Human-Machine-Interfaces (HMI) oder andere Steuerungen aus anderen Anlagen sein.

Die Aggregation der Messwerte soll unabhängig von Modell und Auslegung der Anlage möglich sein. Es werden verschiedene Wege in Betracht gezogen und schießlich einer von diesen an einer echten Anlage getestet. Die dafür notwendigen Komponenten sollten leicht in den bestehenden Aufbau integrierbar sein. 
Zunächst sollen die elektrische Versorgung, die Ströme einzelner Baugruppen und der Status der zentralen Steuerung der Anlage erfasst werden. Der dabei verwendete Messintervall sollte klein genug sein, um zwischen den Prozessschritten der Anlage unterscheiden zu können.Während der Entwicklung ist es auch sinnvoll die Rohwerte der Messungen zu sichern, um den Analyseschritt mit Hilfe von echten Messwerten exemplarisch zu testen.

Je präziser die Datenverarbeitung angesetzt ist, desto weniger Daten müssen anschließend gespeichert werden. In allen Fällen sind die zu speichernden Werte periodische Kennzahlen der einzelnen Prozessschritte, welche in einer zeitbasierten Datenbank abgelegt werden müssen. Nur wenn eine Kennzahl ein festgelegtes Limit überschreitet ist eine direkte Meldung des Wertes notwendig. Um eine zuverlässige Speicherung zu garantieren sollten die Daten möglichst auf mehreren unabhängigen Systemen gespeichert werden. Hierzu wird ein modularer Aufbau verwendet, der es auch ermöglicht unterschiedlichste Speichermethoden gleichzeitig zu verwenden. Schließlich ist auch eine Löschungsstategie notwendig, um zu garantieren, dass immer genug Speicherplatz für neue Daten vorhanden ist.

Die Visualisierung kann dank der vorbereiteten Datensätze im einfachsten Fall aus dem Plotten der Messreihen aus einer der Datenbanken bestehen. 

- fehlende Energieerfassung
- Aufzeichnung von Anlagenzuständen in einer Datenbank
  - Korrelation mit Leistungswerten
  - Integration in den vorhandenen Aufbau

## Topologie der Kernschießmaschinen

Die Kommunikationsstruktur von industrielle Anlagen werden in 3 Ebenen unterteilt:

1. Feldebene
2. Kontrollebene
3. Überwachungsebene

In der Feldebene befinden sich alle Sensoren (Temperatursensoren, Lagesensoren, etc.) und Aktoren wie Motoren, Ventile und Signalgeber. Sie sind über Feldbusverteiler mit der nächst höheren Kontrollebene verbunden. Bei Laempe wird neben traditionellen analog verbundenen Geräten hautsächlich auf das IO-Link Bussystem zurückgegriffen. Dadurch sind in allen Teilen ihren Anlagen IO-Link-Feldbusverteiler verbaut, auf die für die Umsetzung der Energiemessung zurückgegriffen werden kann.
Die Kontrollebene besteht aus einer oder mehreren speicherprogrammierbaren Steuerungen (SPS) und ihren untergeordneten Interfacemodulen. Das Zentralmodul einer SPS wird mit einer echtzeitfähigen Sprache programmiert und kommuniziert mit den Interfacemodulen, welche über Erweiterungskarten den verschiedenen Geräten im Feld verbunden sind. Je nach Hersteller kommen hier unterschiedliche Bussysteme zum Einsatz. Deren speziellen Eigenschaften sind im folgenden Kapitel näher erläutert.
Wenn mehrere Steuerungen sich gegenseitig überwachen oder deren Einstellungen über ein Human-Machine-Interface (HMI) angepasst werden können, dann geschieht dies in der Überwachungsebene. Sie ist die höchste Automatisierungsebene, die man am Ort der Anlage vorfinden kann. In ihr befindet sich auch der Hauptteil des Energieüberwachungssystems, da dieses nicht zur Steuerung der Anlage beiträgt.

## Datenbusse

In den Anlagen werden verschiedene Arten von Datenbussen verwendet.

- EtherNet/IP
- ProfiNet
- Modbus TCP