# Theorie

Die abstrakten Ideen aus der Problemstellung können nun in konkrete Lösungen umgesetzt werden. Zuerst werden die benötigten Aufgaben bestimmten Komponenten zugeordnet. Anschließend werden die einzelnen Komponenten genauer beschrieben. Folgende Darstellung zeigt die Zuordnung der Aufgaben zu den Komponenten.

![Bestandteile des Projekts](out/diagrams/datenfluss/Datenfluss.svg)


## Erfassung der Messwerte

Die Aufgabe der Energiemessung wird durch zwei Gruppen von Sensoren übernommen. Die erste Gruppe besteht aus Sensoren, die an der elektrischen Einspeisung der Kernschießmaschine angebracht sind und den kompletten Momentanverbrauch der Anlage messen. Die zweite Gruppe besteht aus Sensoren, die an den einzelnen Komponenten der Anlage angebracht sind und den Verbrauch dieser Komponenten messen. Die Messwerte der beiden Gruppen werden über den internen Datenbus der Anlage an die zentrale Steuerung der nlage übertragen. In der ersten Gruppe werden für jede Phase jeweils Strom, Spannung und deren Beziehung zueinander erfasst. Dies ergibt ein komplettes Bild über den momentanen Leistungsbedarf und den Energieverbrauch der Anlage über einen längeren Zeitraum. Wie in der Darstellung zu sehen ist, wird die zweite Sensorgruppe an der $24\mathrm{V}$ Kleinstspannungsverteilung angebracht. Diese Entscheidung wurde getroffen, da die Steuerspannungsversorgung nach Firmeninterner Beobachtung viel anfälliger für Überlastereignisse ist, als die Versorgung der Niederspannungsverbraucher. Dazu kommt, dass fast jeder Teil der Anlage über diese Versorgung zumindest indirekt gesteurt wird und ein Fehlerfall der $24\mathrm{V}$-Versorgung definitiv Auswirkungen auf die funktionalität der Anlage hat. Die Spannung wird direkt an der $24\mathrm{V}$-Versorgung gemessen. Die Spannung an den einzelnen Komponenten wird nicht gemessen, da diese sich im Idealfall nicht stark von der Versorgungsspannung unterscheidet. Potentielle Abweichungen skalieren bei konstanten Leitungswiderstand auch proportional zu den Strömen, was ein weiterer Grund ist sie nur an einer Stelle zu messen. Es ist auch nicht praktikabel den Strom jeder einzelnen Komponente zu messen, deshalb findet die Messung an einer zentralen Stelle statt, wo mehrere Komponentengruppen mit wenigen dutzend Strommesskanälen abgedeckt werden können. Eine solche für die Messung der $24\mathrm{V}$-Versorgung geeignete Stelle ist in den Kernschießanlagen kurz vor den Potentialklemmen, nämlich da wo sich die elektronischen Untersicherungen befinden. Diese Sicherungen werden, neben den Netzteilen selbst, in der [Implementierung](30_Implementierung.md) für die Messung der Ströme instrumentiert.

Der meist verwendete Feldbus in Laempe-Anlage ist IO-Link. Dieser Bus ist für die Kommunikation mit den Sensoren und Aktoren der Anlage vorgesehen. Die Sensoren werden über den IO-Link-Bus mit Strom versorgt und können so ohne zusätzliche Versorgungsspannung betrieben werden. Die hinzugefügten Energiesensoren werden vorzugsweise auch in dieses Bussystem integriert. Es ist aber auch möglich, die Energiesensoren direkt an das Steuernetzwerk einzubinden. Wenn dies nicht geschehen kann, dann werden die Signale, so wie bei allen anderen Sensoren auch, über Feldbusverteiler beziehungsweise Interfacemodule mit IO-Link-Unterstützung zu der zentralen Steuerung der Anlage geleitet. 

Unabhängig vom Feldbussystem muss eine Abfragerate der Energiesensoren festgelegt werden. Als Referenz wird hier die Taktzeit einer ausgelasteten zentralen Steuerung herangezogen, welche für die Zwecke der hizukommenden Übermittlerrolle der Messwerte zum Verarbeitungssystem nicht unterschritten werden kann. Als oberes Limit ist bei den zu betrachtenden Kernschießanlagen die Dauer der kürzesten Aktorbetätigung der Kernschießmaschine anzusetzen. Nach Aussage der zuständigen Mitarbeiter ist dafür ein Intervall von $100\mathrm{ms}$ ausreichend. In Kombination der beiden Grenzwerte wird daher je nach Möglichkeit ein Messinterval von $20\mathrm{ms}$ angestrebt. Somit können auch sehr kurzzeitige Fehlerereignisse erkannt und analysiert werden. 

## Übertragung der Messwerte

Für dieses Projekt ist neben den bereits genannten Standardkomponenten der Energiesensoren, Feldbusverteilern und Interfacemodulen auch ein Computer (Box-PC) hinzuzufügen, welcher die Aufgabe der Verarbeitung der aufgenommenen Messwerte übernimmt. Ein solcher Computer ist in der Lage mit der zentralen Steuerung (SPS) der Anlage zu kommunizieren und von ihr Daten abzufragen. Die SPS ist daher so zu konfigurieren, dass sie zusätzlich zu ihrer Haupaufgabe, die Anlage zu steuern, auch die Daten von den neu hinzugefügten Sensoren an den PC weiterreicht. Hierzu können zwei Methoden verwendet werden: Zum Einen kann der Box-PC die von der SPS gesammelten Messwerte periodisch abfragen und zum Anderen kann die SPS die Daten selbstständig zum PC übermitteln. In beiden Fällen muss jedoch ein Protokoll verwendet werden, welches von beiden Seiten unterstützt wird. Es ist beispielsweise nicht möglich ProfiNet Pakete über eine Ethernetverbindung mit einem generischen Linuxkernel zu empfangen, weil dieser nicht in der Lage ist das Echtzeitkriterium des ProfiNet-Standards zu erfüllen. []

Zusätzlich zu den Energiewerten werden, wie in der Darstellung zu sehen ist, auch Statusinformationen der Kernschießmaschine gesammelt und ausgewertet. Diese helfen die Strommessungen in einem zeitlichen Kontext einzuordnen und somit die Qualität der Analyse zu verbessern. Als Datenpunkte sind hier haupsächlich die Befehle der Steuerung an die Aktoren von Interesse, denn diese Informationen lassen sich gut zu den Verbräuchen der aktivierten Komponenten zuordnen. Während der Datenverarbeitung kann somit beispielsweise gezielt nach Anlagenzuständen gefiltert werden oder es können langfristige Veränderungen der Energieverbräuche auf einen bestimmten Prozessschritt zurückgeführt werden.

## Datenverarbeitung

Die Verarbeitung findet auf einer PC-Platform statt, so dass sie flexibel eingesetzt und ohne großen Aufwand modifiziert werden kann. Sie kann dadurch beispielsweise vor Ort auf einem industriellen Box-PC, oder auch über eine Netzwerkverbindung aus einem entfernten Datenzentrum durchgeführt werden. Aus sicherheitstechnischen Gründen darf die verwendete Platform nur lesend über die erhobenen Messwerte verfügen und nicht in den Prozessablauf der Anlage eingreifen. In diesem Schritt wird zuerst periodisch mit den datenübermittelnden Komponenten der Aufbaus kommuniziert, um dann anschließend die erhaltenen Datensätze für die weitere Verarbeitung bereitzuhalten. Diese Komponenten können zum Beispiel die zentrale Steuerung der Kernschießmaschine, einzelne Interfacemodule oder netzwerkfähige Energiesensoren aus dem vorherigen Kapitel sein. Jeder erhaltene Datensatz wird nun mit einem genauen Zeitstempel der PC-Platform bestückt, um bei der folgenden asynchronen Weiterverarbeitung die zeitlich korrekte Reihenfolge der Datensätze der verschiedenen Quellen sicherzustellen. 

werden zuerst die Verbrauchswerte wie Ströme und Spannungen mit dem Status der Anlagensteuerung kombiniert, so dass pro Prozessschritt ein wiederholbares Datenbild entsteht. Ein Prozessschritt ist ein zeitlich begrenzter Zustand der Anlage, in der eine bestimmte Gruppe von Aktoren aktiviert wird. Dies kann beispielsweise das Einfahren des Hubtisches sein. Die elektrischen Verbräuche während dieses Schrittes können so als Funktion der Schrittnummer und Zeit nach Beginn des Vorgangs dargestellt werden. Das Datenbild besteht dann im einfachsten Fall aus Versorgungsleistungen und Strömen der 24V-Kanäle. 

Nun werden die Differenzen des Datenbildes zwischen dem Ausgangszustand und der Aktivierung eines Prozessschrittes berechnet. Dadurch können die Verbräuche der jeweiligen Prozessschritte von den Standbyströmen der inaktiven Komponenten der Anlage isoliert werden. Der Ausgangszustand sollte zeitlich nah am Messvorgang gesetzt sind, damit äußere Einflüsse wie Versorgungsspannung und Umgebungstemperatur einen geringeren Effekt auf die berechneten Differenzen haben.

Anschließend werden je nach erwartetem zeitlichen Verlaufs des Datenbilds einige Aggregationen wie Durchschnitt, Maximum oder Varianz einzelner Kanäle erhoben, um schließlich einfache Kennzahlen für diesen Schritt zu erhalten. Damit können nun Aussagen wie beispielsweise `Das für den Hubtisch zuständige Ventil hat beim zweitausendsten Aktivieren einen Strom von 1,3A verbraucht` getroffen werden.

## Datenspeicherung



## Visualisierung

Je nach Bedarf kann die Visualisierung vor Ort am HMI der Anlagen erfolgen oder auch beispielsweise über einen Browser auf einem entfernten PC. Hier besteht kein großer Entwicklungsbedarf und es kann deswegen auch auf fertige universelle Visualisierungsoberflächen zurückgegriffen werden. 