# Masterarbeit: Energiemonitoring zur Prozessanalyse in industriellen Anlagen am Beispiel von Kernschießmaschinen

Es soll ein Energiemonitoringsystem für die Laempe Mössner Sinto GmbH entwickelt werden, das in möglichst vielen unterschiedlichen elektrischen Anlagen eingesetzt werden kann, um Prozesse einer Kernschießmaschine und deren Energie im Einzelnen wie auch bilanziert zu erfassen und zu evaluieren.

Der feste Bestandteil des Systems soll in der Lage sein, Ströme und Spannungen durch zu konzeptionierende Teilsysteme für die Einspeisung bis 3x480 V AC sowie für die Steuerspannung 24 V DC zur SPS-, Aktor- und Sensorversorgung mittels geeigneter Sensoren und Signalkonzentratoren entsprechend dem Stand der Technik zu erfassen und zu messen.

Zur Selektierung der Hardwarekomponenten muss eine universale Softwareschnittstelle geschaffen werden, damit die Weiterverarbeitung der Messdaten in aufbereiteter Form zur Auswertung und Darstellung in allen Anlagentypen und steuerungsspezifisch gleichermaßen stattfinden kann.

Hierfür soll das System zum Energiemonitoring an einem Versuchsstand aufgebaut, in Betrieb genommen und entsprechend seiner Güte evaluiert werden.

Gegeben sind folgende speicherprogrammierbaren Steuerungen, dezentrale Peripherien und deren Feldbusse, auf welche das System applizierbar sein muss.

- Siemens
    - CPU: SIMATIC S7-1500 vgl. 1515F-2 PN
    - Dezentrale Peripherie: SIMATIC ET 200SP
    - Feldbus: Profinet
- Allen-Bradley / Rockwell Automation 
    - CPU: Compact Logix vlg. 5069-L310ERMS3
    - Dezentrale Peripherie: Point IO – 1734 Serie
    - Feldbus: Ethernet IP
- Mitsubishi
    - CPU: MELSEC iQ-R vlg. R08SFCPU-SET
    - Feldbus: CC-Link IE Field

![Datenfluss](out/diagrams/datenfluss/Datenfluss.svg)

# Implementierung
- [Image für Box-PC](box-pc/)
    - Anwendung: [PLC-Connector](box-pc/plc-connector/)
- [TIA-Portal-Projekt](AI-energy-meter-Project/) für eine temporäre sekundäre Steuerung

- Datenanalyse [mit R-Studio](analyse/)

# WIP Kapitel
- [x] [Einleitung](00_Einleitung.md)
- [ ] [Grundlagen](10_Grundlagen.md)
  - [ ] Was sind Kernschießmaschinen
  - [x] Problemstellung
  - [ ] Topologie der Kernschießmaschinen
  - [ ] typische Datenbusse
- [ ] [Bestandteile der Energieüberwachung](20_Theorie.md)
  - [ ] Erfassung der Einspeisung
      - [ ] am Hauptschalter
      - [ ] mit einer analogen Messkarte
      - [ ] mit einem Stromzähler
      - [ ] mit einem Energiemeter
  - [ ] Erfassung der Steuerströme
      - [ ] mit Stromshunts
      - [ ] am Netzteil
      - [ ] an den elektronischen Sicherungen
  - [ ] Datenverarbeitung
  - [ ] Datenspeicherung
  - [ ] Visualisierung
- [ ] [Implementierung](30_Implementierung.md)
  - [ ] Wahl der Sensoren
  - [ ] Software
- [ ] [Praktische Versuche](40_Praxis.md)
  - [x] Testaufbau
  - [x] Messung an kompletten Kernschießmaschinen
      - [ ] Analyse der Rohdaten
  - [ ] Ergebnisse
  - [ ] Erarbeitung der Meldungskriterien
- [ ] [Zusammenfassung](50_Zusammenfassung.md)


# finales Dokument
- [ ] [in LaTeX](main.tex)